@@ -4,7 +4,7 @@
 	 * Central phpPgAdmin configuration.  As a user you may modify the
 	 * settings here for your particular configuration.
 	 *
-	 * $Id: config.inc.php-dist,v 1.49 2006/08/04 20:42:24 xzilla Exp $
+	 * $Id: config.inc.php-dist,v 1.55 2008/02/18 21:10:31 xzilla Exp $
 	 */
 
 	// An example server.  Create as many of these as you wish,
@@ -22,10 +22,12 @@
 
 	// Database SSL mode
 	// Possible options: disable, allow, prefer, require
+	// To require SSL on older servers use option: legacy
+	// To ignore the SSL mode, use option: unspecified
 	$conf['servers'][0]['sslmode'] = 'allow';
 
 	// Change the default database only if you cannot connect to template1.
-	// For a PostgreSQL 8.1 server, you need to set this to 'postgres'.
+	// For a PostgreSQL 8.1+ server, you can set this to 'postgres'.
 	$conf['servers'][0]['defaultdb'] = 'template1';
 
 	// Specify the path to the database dump utilities for this server.
@@ -50,14 +52,14 @@
 	//$conf['servers'][1]['slony_support'] = false;
 	//$conf['servers'][1]['slony_sql'] = 'C:\\Program Files\\PostgreSQL\\8.0\\share';
 
-	// Default language. Eg: 'english', 'polish', etc.  See lang/ directory
+	// Default language. E.g.: 'english', 'polish', etc.  See lang/ directory
 	// for all possibilities. If you specify 'auto' (the default) it will use 
 	// your browser preference.
 	$conf['default_lang'] = 'auto';
 
-	// AutoComplete uses ajaxy interaction to list FK options on insert fields
-    // It currently only works on single column foreign keys. You can control
-	// it's behavior with the following settings.  
+	// AutoComplete uses AJAX interaction to list foreign key values 
+	// on insert fields. It currently only works on single column 
+	// foreign keys. You can choose one of the following values:
 	// 'default on' enables AutoComplete and turns it on by default.
 	// 'default off' enables AutoComplete but turns it off by default.
 	// 'disable' disables AutoComplete.
@@ -73,16 +75,17 @@
 	// Only show owned databases?
 	// Note: This will simply hide other databases in the list - this does
 	// not in any way prevent your users from seeing other database by
-	// other means. (eg. Run 'SELECT * FROM pg_database' in the SQL area.)
+	// other means. (e.g. Run 'SELECT * FROM pg_database' in the SQL area.)
 	$conf['owned_only'] = false;
 
 	// Display comments on objects?  Comments are a good way of documenting
 	// a database, but they do take up space in the interface.
 	$conf['show_comments'] = true;
 
-	// Display "advanced" objects?  Setting this to true will show types,
-	// operators conversions, languages and casts in phpPgAdmin.  These
-	// objects are rarely administered and can clutter the interface.
+	// Display "advanced" objects? Setting this to true will show 
+	// aggregates, types, operators, operator classes, conversions, 
+	// languages and casts in phpPgAdmin. These objects are rarely 
+	// administered and can clutter the interface.
 	$conf['show_advanced'] = false;
 
 	// Display "system" objects?
@@ -92,6 +95,11 @@
 	// install the reports database as explained in the INSTALL file.
 	$conf['show_reports'] = true;
 
+	// Database and table for reports
+	$conf['reports_db'] = 'phppgadmin';
+	$conf['reports_schema'] = 'public';
+	$conf['reports_table'] = 'ppa_reports';
+
 	// Only show owned reports?
 	// Note: This does not prevent people from accessing other reports by
 	// other means.
@@ -115,18 +123,18 @@
 	// Max chars of each field to display by default in browse mode
 	$conf['max_chars'] = 50;
 
-	// Send XHTML headers?  Unless debugging, it's best to leave this off
-	$conf['use_xhtml'] = false;
+	// Send XHTML strict headers?
+	$conf['use_xhtml_strict'] = false;
 
 	// Base URL for PostgreSQL documentation.
 	// '%s', if present, will be replaced with the PostgreSQL version
-	// (7, 7.1, 7.2, 7.3, 7.4, or 8.0)
+	// (e.g. 7.3 )
 	$conf['help_base'] = 'http://www.postgresql.org/docs/%s/interactive/';
 	
 	/*****************************************
 	 * Don't modify anything below this line *
 	 *****************************************/
 
-	$conf['version'] = 17;
+	$conf['version'] = 19;
 
 ?>
