@@ -4,7 +4,7 @@
 	 * English language file for phpPgAdmin.  Use this as a basis
 	 * for new translations.
 	 *
-	 * $Id: english.php,v 1.198.2.3 2007/07/09 14:55:23 xzilla Exp $
+	 * $Id: english.php,v 1.232 2008/02/23 16:34:33 ioguix Exp $
 	 */
 
 	// Language and character set
@@ -14,7 +14,7 @@
 	$lang['appdbencoding'] = 'LATIN1';
 	$lang['applangdir'] = 'ltr';
 
-	// Welcome  
+	// Welcome
 	$lang['strintro'] = 'Welcome to phpPgAdmin.';
 	$lang['strppahome'] = 'phpPgAdmin Homepage';
 	$lang['strpgsqlhome'] = 'PostgreSQL Homepage';
@@ -91,7 +91,6 @@
 	$lang['strimport'] = 'Import';
 	$lang['strallowednulls'] = 'Allowed NULL characters';
 	$lang['strbackslashn'] = '\N';
-	$lang['strnull'] = 'NULL (The word)';
 	$lang['stremptystring'] = 'Empty string/field';
 	$lang['strsql'] = 'SQL';
 	$lang['stradmin'] = 'Admin';
@@ -100,9 +99,8 @@
 	$lang['strclusterindex'] = 'Cluster';
 	$lang['strclustered'] = 'Clustered?';
 	$lang['strreindex'] = 'Reindex';
-	$lang['strrun'] = 'Run';
+	$lang['strexecute'] = 'Execute';
 	$lang['stradd'] = 'Add';
-	$lang['strremove'] = 'Remove';
 	$lang['strevent'] = 'Event';
 	$lang['strwhere'] = 'Where';
 	$lang['strinstead'] = 'Do Instead';
@@ -115,8 +113,6 @@
 	$lang['strseparator'] = ': ';
 	$lang['strexpand'] = 'Expand';
 	$lang['strcollapse'] = 'Collapse';
-	$lang['strexplain'] = 'Explain';
-	$lang['strexplainanalyze'] = 'Explain Analyze';
 	$lang['strfind'] = 'Find';
 	$lang['stroptions'] = 'Options';
 	$lang['strrefresh'] = 'Refresh';
@@ -137,8 +133,22 @@
 	$lang['strfile'] = 'File';
 	$lang['strfileimported'] = 'File imported.';
 	$lang['strtrycred'] = 'Use these credentials for all servers';
+	$lang['strconfdropcred'] = 'For security reason, disconnecting will destroy your shared login information. Are you sure you want to disconnect ?';
+	$lang['stractionsonmultiplelines'] = 'Actions on multiple lines';
+	$lang['strselectall'] = 'Select all';
+	$lang['strunselectall'] = 'Unselect all';
+	$lang['strlocale'] = 'Locale';
 
-	// Database Sizes
+	// User-supplied SQL history
+	$lang['strhistory'] = 'History';
+	$lang['strnohistory'] = 'No history.';
+	$lang['strclearhistory'] = 'Clear history';
+	$lang['strdelhistory'] = 'Delete from history';
+	$lang['strconfdelhistory'] = 'Really remove this request from history?';
+	$lang['strconfclearhistory'] = 'Really clear history?';
+	$lang['strnodatabaseselected'] = 'Please, select a database.';
+
+	// Database sizes
 	$lang['strsize'] = 'Size';
 	$lang['strbytes'] = 'bytes';
 	$lang['strkb'] = 'kB';
@@ -165,10 +175,11 @@
 	$lang['strimporterror'] = 'Import error.';
 	$lang['strimporterror-fileformat'] = 'Import error: Failed to automatically determine the file format.';
 	$lang['strimporterrorline'] = 'Import error on line %s.';
-	$lang['strimporterrorline-badcolumnnum'] = 'Import error on line %s:  Line does not possess the correct number of columns.';
+	$lang['strimporterrorline-badcolumnnum'] = 'Import error on line %s: Line does not possess the correct number of columns.';
 	$lang['strimporterror-uploadedfile'] = 'Import error: File could not be uploaded to the server';
 	$lang['strcannotdumponwindows'] = 'Dumping of complex table and schema names on Windows is not supported.';
 	$lang['strinvalidserverparam'] = 'Attempt to connect with invalid server parameter, possibly someone is trying to hack your system.'; 
+	$lang['strnoserversupplied'] = 'No server supplied!';
 
 	// Tables
 	$lang['strtable'] = 'Table';
@@ -177,8 +188,14 @@
 	$lang['strnotables'] = 'No tables found.';
 	$lang['strnotable'] = 'No table found.';
 	$lang['strcreatetable'] = 'Create table';
+	$lang['strcreatetablelike'] = 'Create table like';
+	$lang['strcreatetablelikeparent'] = 'Source table';
+	$lang['strcreatelikewithdefaults'] = 'INCLUDE DEFAULTS';
+	$lang['strcreatelikewithconstraints'] = 'INCLUDE CONSTRAINTS';
+	$lang['strcreatelikewithindexes'] = 'INCLUDE INDEXES';
 	$lang['strtablename'] = 'Table name';
 	$lang['strtableneedsname'] = 'You must give a name for your table.';
+	$lang['strtablelikeneedslike'] = 'You must give a table to copy properties from.';
 	$lang['strtableneedsfield'] = 'You must specify at least one field.';
 	$lang['strtableneedscols'] = 'You must specify a valid number of columns.';
 	$lang['strtablecreated'] = 'Table created.';
@@ -206,7 +223,6 @@
 	$lang['strselectallfields'] = 'Select all fields';
 	$lang['strselectneedscol'] = 'You must show at least one column.';
 	$lang['strselectunary'] = 'Unary operators cannot have values.';
-	$lang['straltercolumn'] = 'Alter column';
 	$lang['strcolumnaltered'] = 'Column altered.';
 	$lang['strcolumnalteredbad'] = 'Column alteration failed.';
 	$lang['strconfdropcolumn'] = 'Are you sure you want to drop column "%s" from table "%s"?';
@@ -224,10 +240,16 @@
 	$lang['strtabbed'] = 'Tabbed';
 	$lang['strauto'] = 'Auto';
 	$lang['strconfvacuumtable'] = 'Are you sure you want to vacuum "%s"?';
+	$lang['strconfanalyzetable'] = 'Are you sure you want to analyze "%s"?';
 	$lang['strestimatedrowcount'] = 'Estimated row count';
+	$lang['strspecifytabletoanalyze'] = 'You must specify at least one table to analyze.';
+	$lang['strspecifytabletoempty'] = 'You must specify at least one table to empty.';
+	$lang['strspecifytabletodrop'] = 'You must specify at least one table to drop.';
+	$lang['strspecifytabletovacuum'] = 'You must specify at least one table to vacuum.';
 
 	// Columns
-	$lang['strcolprop'] = 'Column Properties';
+	$lang['strcolprop'] = 'Column properties';
+	$lang['strnotableprovided'] = 'No table provided!';
 		
 	// Users
 	$lang['struser'] = 'User';
@@ -259,10 +281,10 @@
 	// Groups
 	$lang['strgroup'] = 'Group';
 	$lang['strgroups'] = 'Groups';
+	$lang['strshowallgroups'] = 'Show all groups';
 	$lang['strnogroup'] = 'Group not found.';
 	$lang['strnogroups'] = 'No groups found.';
 	$lang['strcreategroup'] = 'Create group';
-	$lang['strshowallgroups'] = 'Show all groups';
 	$lang['strgroupneedsname'] = 'You must give a name for your group.';
 	$lang['strgroupcreated'] = 'Group created.';
 	$lang['strgroupcreatedbad'] = 'Group creation failed.';	
@@ -279,29 +301,25 @@
 	$lang['strconfdropmember'] = 'Are you sure you want to drop the member "%s" from the group "%s"?';
 	$lang['strmemberdropped'] = 'Member dropped.';
 	$lang['strmemberdroppedbad'] = 'Member drop failed.';
-	
+
 	// Roles
 	$lang['strrole'] = 'Role';
 	$lang['strroles'] = 'Roles';
-	$lang['strrolename'] = 'Rolename';
 	$lang['strshowallroles'] = 'Show all roles';
+	$lang['strnoroles'] = 'No roles found.';
 	$lang['strinheritsprivs'] = 'Inherits privileges?';
 	$lang['strcreaterole'] = 'Create role';
-	$lang['strcancreaterole'] = 'Create role?';
+	$lang['strcancreaterole'] = 'Can create role?';
 	$lang['strrolecreated'] = 'Role created.';
 	$lang['strrolecreatedbad'] = 'Create role failed.';
-	$lang['stralterrole'] = 'Alter role';
-	$lang['strroleupdated'] = 'Role updated.';
-	$lang['strroleupdatedbad'] = 'Role update failed.';
-	$lang['strcatupdate'] = 'Modify catalogs?';
+	$lang['strrolealtered'] = 'Role altered.';
+	$lang['strrolealteredbad'] = 'Role alter failed.';
 	$lang['strcanlogin'] = 'Can login?';
 	$lang['strconnlimit'] = 'Connection limit';
 	$lang['strdroprole'] = 'Drop role';
-	$lang['strmaxconnections'] = 'Max connections';
 	$lang['strconfdroprole'] = 'Are you sure you want to drop the role "%s"?';
 	$lang['strroledropped'] = 'Role dropped.';
 	$lang['strroledroppedbad'] = 'Role drop failed.';
-	$lang['strnoroles'] = 'No roles found.';
 	$lang['strnolimit'] = 'No limit';
 	$lang['strnever'] = 'Never';
 	$lang['strroleneedsname'] = 'You must give a name for the role.';
@@ -322,7 +340,6 @@
 	$lang['strdatabase'] = 'Database';
 	$lang['strdatabases'] = 'Databases';
 	$lang['strshowalldatabases'] = 'Show all databases';
-	$lang['strnodatabase'] = 'No database found.';
 	$lang['strnodatabases'] = 'No databases found.';
 	$lang['strcreatedatabase'] = 'Create database';
 	$lang['strdatabasename'] = 'Database name';
@@ -348,6 +365,7 @@
 	$lang['strallobjects'] = 'All objects';
 	$lang['strdatabasealtered'] = 'Database altered.';
 	$lang['strdatabasealteredbad'] = 'Database alter failed.';
+	$lang['strspecifydatabasetodrop'] = 'You must specify at least one database to drop.';
 
 	// Views
 	$lang['strview'] = 'View';
@@ -370,6 +388,12 @@
 	$lang['strviewlink'] = 'Linking keys';
 	$lang['strviewconditions'] = 'Additional conditions';
 	$lang['strcreateviewwiz'] = 'Create view with wizard';
+	$lang['strrenamedupfields'] = 'Rename duplicate fields';
+	$lang['strdropdupfields'] = 'Drop duplicate fields';
+	$lang['strerrordupfields'] = 'Error on duplicate fields';
+	$lang['strviewaltered'] = 'View altered.';
+	$lang['strviewalteredbad'] = 'View alteration failed.';
+	$lang['strspecifyviewtodrop'] = 'You must specify at least one view to drop.';
 
 	// Sequences
 	$lang['strsequence'] = 'Sequence';
@@ -385,17 +409,16 @@
 	$lang['strminvalue'] = 'Min value';
 	$lang['strcachevalue'] = 'Cache value';
 	$lang['strlogcount'] = 'Log count';
-	$lang['striscycled'] = 'Is cycled?';
-	$lang['striscalled'] = 'Is called?';
+	$lang['strcancycle'] = 'Can cycle?';
+	$lang['striscalled'] = 'Will increment last value before returning next value (is_called)?';
 	$lang['strsequenceneedsname'] = 'You must specify a name for your sequence.';
 	$lang['strsequencecreated'] = 'Sequence created.';
-	$lang['strsequencecreatedbad'] = 'Sequence creation failed.'; 
+	$lang['strsequencecreatedbad'] = 'Sequence creation failed.';
 	$lang['strconfdropsequence'] = 'Are you sure you want to drop sequence "%s"?';
 	$lang['strsequencedropped'] = 'Sequence dropped.';
 	$lang['strsequencedroppedbad'] = 'Sequence drop failed.';
 	$lang['strsequencereset'] = 'Sequence reset.';
-	$lang['strsequenceresetbad'] = 'Sequence reset failed.'; 
- 	$lang['straltersequence'] = 'Alter sequence';
+	$lang['strsequenceresetbad'] = 'Sequence reset failed.';
  	$lang['strsequencealtered'] = 'Sequence altered.';
  	$lang['strsequencealteredbad'] = 'Sequence alteration failed.';
  	$lang['strsetval'] = 'Set value';
@@ -404,7 +427,8 @@
  	$lang['strnextval'] = 'Increment value';
  	$lang['strsequencenextval'] = 'Sequence incremented.';
  	$lang['strsequencenextvalbad'] = 'Sequence increment failed.';
-
+	$lang['strspecifysequencetodrop'] = 'You must specify at least one sequence to drop.';
+	
 	// Indexes
 	$lang['strindex'] = 'Index';
 	$lang['strindexes'] = 'Indexes';
@@ -417,7 +441,7 @@
 	$lang['strcolumnname'] = 'Column name';
 	$lang['strindexneedsname'] = 'You must give a name for your index.';
 	$lang['strindexneedscols'] = 'Indexes require a valid number of columns.';
-	$lang['strindexcreated'] = 'Index created';
+	$lang['strindexcreated'] = 'Index created.';
 	$lang['strindexcreatedbad'] = 'Index creation failed.';
 	$lang['strconfdropindex'] = 'Are you sure you want to drop the index "%s"?';
 	$lang['strindexdropped'] = 'Index dropped.';
@@ -504,7 +528,6 @@
 	$lang['strobjectfile'] = 'Object File';
 	$lang['strlinksymbol'] = 'Link Symbol';
 	$lang['strarguments'] = 'Arguments';
-	$lang['strargname'] = 'Name';
 	$lang['strargmode'] = 'Mode';
 	$lang['strargtype'] = 'Type';
 	$lang['strargadd'] = 'Add another argument';
@@ -516,7 +539,10 @@
 	$lang['strargraise'] = 'Move up.';
 	$lang['strarglower'] = 'Move down.';
 	$lang['strargremoveconfirm'] = 'Are you sure you want to remove this argument? This CANNOT be undone.';
-
+	$lang['strfunctioncosting'] = 'Function Costing';
+	$lang['strresultrows'] = 'Result Rows';
+	$lang['strexecutioncost'] = 'Execution Cost';
+	$lang['strspecifyfunctiontodrop'] = 'You must specify at least one function to drop.';
 
 	// Triggers
 	$lang['strtrigger'] = 'Trigger';
@@ -550,9 +576,11 @@
 	$lang['strnotypes'] = 'No types found.';
 	$lang['strcreatetype'] = 'Create type';
 	$lang['strcreatecomptype'] = 'Create composite type';
+	$lang['strcreateenumtype'] = 'Create enum type';
 	$lang['strtypeneedsfield'] = 'You must specify at least one field.';
-	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';	
-	$lang['strtypename'] = 'Type name';
+	$lang['strtypeneedsvalue'] = 'You must specify at least one value.';
+	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';
+	$lang['strtypeneedsvals'] = 'You must specify a valid number of values.';
 	$lang['strinputfn'] = 'Input function';
 	$lang['stroutputfn'] = 'Output function';
 	$lang['strpassbyval'] = 'Passed by val?';
@@ -562,9 +590,10 @@
 	$lang['strstorage'] = 'Storage';
 	$lang['strfield'] = 'Field';
 	$lang['strnumfields'] = 'Num. of fields';
+	$lang['strnumvalues'] = 'Num. of values';
 	$lang['strtypeneedsname'] = 'You must give a name for your type.';
 	$lang['strtypeneedslen'] = 'You must give a length for your type.';
-	$lang['strtypecreated'] = 'Type created';
+	$lang['strtypecreated'] = 'Type created.';
 	$lang['strtypecreatedbad'] = 'Type creation failed.';
 	$lang['strconfdroptype'] = 'Are you sure you want to drop the type "%s"?';
 	$lang['strtypedropped'] = 'Type dropped.';
@@ -573,6 +602,8 @@
 	$lang['strbasetype'] = 'Base';
 	$lang['strcompositetype'] = 'Composite';
 	$lang['strpseudotype'] = 'Pseudo';
+	$lang['strenum'] = 'Enum';
+	$lang['strenumvalues'] = 'Enum values';
 
 	// Schemas
 	$lang['strschema'] = 'Schema';
@@ -583,7 +614,7 @@
 	$lang['strcreateschema'] = 'Create schema';
 	$lang['strschemaname'] = 'Schema name';
 	$lang['strschemaneedsname'] = 'You must give a name for your schema.';
-	$lang['strschemacreated'] = 'Schema created';
+	$lang['strschemacreated'] = 'Schema created.';
 	$lang['strschemacreatedbad'] = 'Schema creation failed.';
 	$lang['strconfdropschema'] = 'Are you sure you want to drop the schema "%s"?';
 	$lang['strschemadropped'] = 'Schema dropped.';
@@ -591,6 +622,7 @@
 	$lang['strschemaaltered'] = 'Schema altered.';
 	$lang['strschemaalteredbad'] = 'Schema alteration failed.';
 	$lang['strsearchpath'] = 'Schema search path';
+	$lang['strspecifyschematodrop'] = 'You must specify at least one schema to drop.';
 
 	// Reports
 	$lang['strreport'] = 'Report';
@@ -641,7 +673,7 @@
 	$lang['strlessthan'] = 'Less than';
 	$lang['strgreaterthan'] = 'Greater than';
 	$lang['stroperatorneedsname'] = 'You must give a name for your operator.';
-	$lang['stroperatorcreated'] = 'Operator created';
+	$lang['stroperatorcreated'] = 'Operator created.';
 	$lang['stroperatorcreatedbad'] = 'Operator creation failed.';
 	$lang['strconfdropoperator'] = 'Are you sure you want to drop the operator "%s"?';
 	$lang['stroperatordropped'] = 'Operator dropped.';
@@ -678,25 +710,22 @@
 	$lang['straggregates'] = 'Aggregates';
 	$lang['strnoaggregates'] = 'No aggregates found.';
 	$lang['stralltypes'] = '(All types)';
-	$lang['straggrtransfn'] = 'Transition function';
 	$lang['strcreateaggregate'] = 'Create aggregate';
 	$lang['straggrbasetype'] = 'Input data type';
 	$lang['straggrsfunc'] = 'State transition function';
-	$lang['straggrstype'] = 'State data type';
+	$lang['straggrstype'] = 'Data type for state value';
 	$lang['straggrffunc'] = 'Final function';
 	$lang['straggrinitcond'] = 'Initial condition';
 	$lang['straggrsortop'] = 'Sort operator';
-	$lang['strdropaggregate'] = 'Drop aggregate';
 	$lang['strconfdropaggregate'] = 'Are you sure you want to drop the aggregate "%s"?';
 	$lang['straggregatedropped'] = 'Aggregate dropped.';
 	$lang['straggregatedroppedbad'] = 'Aggregate drop failed.';
-	$lang['stralteraggregate'] = 'Alter aggregate';
 	$lang['straggraltered'] = 'Aggregate altered.';
 	$lang['straggralteredbad'] = 'Aggregate alteration failed.';
-	$lang['straggrneedsname'] = 'You must specify a name for the aggregate';
-	$lang['straggrneedsbasetype'] = 'You must specify the input data type for the aggregate';
-	$lang['straggrneedssfunc'] = 'You must specify the name of the state transition function for the aggregate';
-	$lang['straggrneedsstype'] = 'You must specify the data type for the aggregate\'s state value';
+	$lang['straggrneedsname'] = 'You must specify a name for the aggregate.';
+	$lang['straggrneedsbasetype'] = 'You must specify the input data type for the aggregate.';
+	$lang['straggrneedssfunc'] = 'You must specify the name of the state transition function for the aggregate.';
+	$lang['straggrneedsstype'] = 'You must specify the data type for the aggregate\'s state value.';
 	$lang['straggrcreated'] = 'Aggregate created.';
 	$lang['straggrcreatedbad'] = 'Aggregate creation failed.';
 	$lang['straggrshowall'] = 'Show all aggregates';
@@ -751,7 +780,7 @@
 	$lang['strclustercreatedbad'] = 'Cluster initialization failed.';
 	$lang['strclusterneedsname'] = 'You must give a name for the cluster.';
 	$lang['strclusterneedsnodeid'] = 'You must give an ID for the local node.';
-	
+
 	// Slony nodes
 	$lang['strnodes'] = 'Nodes';
 	$lang['strnonodes'] = 'No nodes found.';
@@ -762,16 +791,15 @@
 	$lang['strnodecreatedbad'] = 'Node creation failed.';
 	$lang['strconfdropnode'] = 'Are you sure you want to drop node "%s"?';
 	$lang['strnodedropped'] = 'Node dropped.';
-	$lang['strnodedroppedbad'] = 'Node drop failed';
+	$lang['strnodedroppedbad'] = 'Node drop failed.';
 	$lang['strfailover'] = 'Failover';
 	$lang['strnodefailedover'] = 'Node failed over.';
 	$lang['strnodefailedoverbad'] = 'Node failover failed.';
 	$lang['strstatus'] = 'Status';	
 	$lang['strhealthy'] = 'Healthy';
-	$lang['stroutofsync'] = 'Out of Sync';
+	$lang['stroutofsync'] = 'Out of sync';
 	$lang['strunknown'] = 'Unknown';	
 
-	
 	// Slony paths	
 	$lang['strpaths'] = 'Paths';
 	$lang['strnopaths'] = 'No paths found.';
@@ -825,7 +853,6 @@
 	$lang['strconfunlockrepset'] = 'Are you sure you want to unlock replication set "%s"?';
 	$lang['strrepsetunlocked'] = 'Replication set unlocked.';
 	$lang['strrepsetunlockedbad'] = 'Replication set unlock failed.';
-	$lang['strexecute'] = 'Execute';
 	$lang['stronlyonnode'] = 'Only on node';
 	$lang['strddlscript'] = 'DDL script';
 	$lang['strscriptneedsbody'] = 'You must supply a script to be executed on all nodes.';
@@ -838,17 +865,17 @@
 	$lang['strtableneedsuniquekey'] = 'Table to be added requires a primary or unique key.';
 	$lang['strtableaddedtorepset'] = 'Table added to replication set.';
 	$lang['strtableaddedtorepsetbad'] = 'Failed adding table to replication set.';
-	$lang['strconfremovetablefromrepset'] = 'Are you sure you want to remove the table "%s" from replication set "%s"?';
-	$lang['strtableremovedfromrepset'] = 'Table removed from replication set.';
-	$lang['strtableremovedfromrepsetbad'] = 'Failed to remove table from replication set.';
+	$lang['strconfremovetablefromrepset'] = 'Are you sure you want to drop the table "%s" from replication set "%s"?';
+	$lang['strtableremovedfromrepset'] = 'Table dropped from replication set.';
+	$lang['strtableremovedfromrepsetbad'] = 'Failed to drop table from replication set.';
 
 	// Slony sequences in replication sets
 	$lang['straddsequence'] = 'Add sequence';
 	$lang['strsequenceaddedtorepset'] = 'Sequence added to replication set.';
 	$lang['strsequenceaddedtorepsetbad'] = 'Failed adding sequence to replication set.';
-	$lang['strconfremovesequencefromrepset'] = 'Are you sure you want to remove the sequence "%s" from replication set "%s"?';
-	$lang['strsequenceremovedfromrepset'] = 'Sequence removed from replication set.';
-	$lang['strsequenceremovedfromrepsetbad'] = 'Failed to remove sequence from replication set.';
+	$lang['strconfremovesequencefromrepset'] = 'Are you sure you want to drop the sequence "%s" from replication set "%s"?';
+	$lang['strsequenceremovedfromrepset'] = 'Sequence dropped from replication set.';
+	$lang['strsequenceremovedfromrepsetbad'] = 'Failed to drop sequence from replication set.';
 
 	// Slony subscriptions
 	$lang['strsubscriptions'] = 'Subscriptions';
@@ -859,6 +886,9 @@
 	$lang['strtimefmt'] = 'jS M, Y g:iA';
 	$lang['strhelp'] = 'Help';
 	$lang['strhelpicon'] = '?';
+	$lang['strhelppagebrowser'] = 'Help page browser';
+	$lang['strselecthelppage'] = 'Select a help page';
+	$lang['strinvalidhelppage'] = 'Invalid help page.';
 	$lang['strlogintitle'] = 'Login to %s';
 	$lang['strlogoutmsg'] = 'Logged out of %s';
 	$lang['strloading'] = 'Loading...';
@@ -866,20 +896,21 @@
 	$lang['strclicktoreload'] = 'Click to reload';
 
 	// Autovacuum
-	$lang['strautovacuum'] = 'Autovacuum'; 
-	$lang['strturnedon'] = 'Turned On'; 
-	$lang['strturnedoff'] = 'Turned Off'; 
-	$lang['strenabled'] = 'Enabled'; 
-	$lang['strvacuumbasethreshold'] = 'Vacuum Base Threshold'; 
-	$lang['strvacuumscalefactor'] = 'Vacuum Scale Factor';  
-	$lang['stranalybasethreshold'] = 'Analyze Base Threshold';  
-	$lang['stranalyzescalefactor'] = 'Analyze Scale Factor'; 
-	$lang['strvacuumcostdelay'] = 'Vacuum Cost Delay'; 
-	$lang['strvacuumcostlimit'] = 'Vacuum Cost Limit';  
+	$lang['strautovacuum'] = 'Autovacuum';
+	$lang['strturnedon'] = 'Turned On';
+	$lang['strturnedoff'] = 'Turned Off';
+	$lang['strenabled'] = 'Enabled';
+	$lang['strvacuumbasethreshold'] = 'Vacuum Base Threshold';
+	$lang['strvacuumscalefactor'] = 'Vacuum Scale Factor';
+	$lang['stranalybasethreshold'] = 'Analyze Base Threshold';
+	$lang['stranalyzescalefactor'] = 'Analyze Scale Factor';
+	$lang['strvacuumcostdelay'] = 'Vacuum Cost Delay';
+	$lang['strvacuumcostlimit'] = 'Vacuum Cost Limit';
 
-    // Table-level Locks
+	// Table-level Locks
 	$lang['strlocks'] = 'Locks';
 	$lang['strtransaction'] = 'Transaction ID';
+	$lang['strvirtualtransaction'] = 'Virtual Transaction ID';
 	$lang['strprocessid'] = 'Process ID';
 	$lang['strmode'] = 'Lock mode';
 	$lang['strislockheld'] = 'Is lock held?';
@@ -888,4 +919,58 @@
 	$lang['strpreparedxacts'] = 'Prepared transactions';
 	$lang['strxactid'] = 'Transaction ID';
 	$lang['strgid'] = 'Global ID';
+	
+	// Fulltext search
+	$lang['strfulltext'] = 'Full Text Search';
+	$lang['strftsconfig'] = 'FTS configuration';
+	$lang['strftsconfigs'] = 'Configurations';
+	$lang['strftscreateconfig'] = 'Create FTS configuration';
+	$lang['strftscreatedict'] = 'Create dictionary';
+	$lang['strftscreatedicttemplate'] = 'Create dictionary template';
+	$lang['strftscreateparser'] = 'Create parser';
+	$lang['strftsnoconfigs'] = 'No FTS configuration found.';
+	$lang['strftsconfigdropped'] = 'FTS configuration dropped.';
+	$lang['strftsconfigdroppedbad'] = 'FTS configuration drop failed.';
+	$lang['strconfdropftsconfig'] = 'Are you sure you want to drop the FTS configuration "%s"?';
+	$lang['strconfdropftsdict'] = 'Are you sure you want to drop the FTS dictionary "%s"?';
+	$lang['strconfdropftsmapping'] = 'Are you sure you want to drop mapping "%s" of FTS configuration "%s"?';
+	$lang['strftstemplate'] = 'Template';
+	$lang['strftsparser'] = 'Parser';
+	$lang['strftsconfigneedsname'] = 'You must give a name for your FTS configuration.';
+	$lang['strftsconfigcreated'] = 'FTS configuration created.';
+	$lang['strftsconfigcreatedbad'] = 'FTS configuration creation failed.';
+	$lang['strftsmapping'] = 'Mapping';
+	$lang['strftsdicts'] = 'Dictionaries';
+	$lang['strftsdict'] = 'Dictionary';
+	$lang['strftsemptymap'] = 'Empty FTS configuration map.';
+	$lang['strftsconfigaltered'] = 'FTS configuration altered.';
+	$lang['strftsconfigalteredbad'] = 'FTS configuration alter failed.';
+	$lang['strftsconfigmap'] = 'FTS configuration map';
+	$lang['strftsparsers'] = 'FTS parsers';
+	$lang['strftsnoparsers'] = 'No FTS parsers available.';
+	$lang['strftsnodicts'] = 'No FTS dictionaries available.';
+	$lang['strftsdictcreated'] = 'FTS dictionary created.';
+	$lang['strftsdictcreatedbad'] = 'FTS dictionary creation failed.';
+	$lang['strftslexize'] = 'Lexize';
+	$lang['strftsinit'] = 'Init';
+	$lang['strftsoptionsvalues'] = 'Options and values';
+	$lang['strftsdictneedsname'] = 'You must give a name for your FTS dictionary.';
+	$lang['strftsdictdropped'] = 'FTS dictionary dropped.';
+	$lang['strftsdictdroppedbad'] = 'FTS dictionary drop failed.';
+	$lang['strftsdictaltered'] = 'FTS dictionary altered.';
+	$lang['strftsdictalteredbad'] = 'FTS dictionary alter failed.';
+	$lang['strftsaddmapping'] = 'Add new mapping';
+	$lang['strftsspecifymappingtodrop'] = 'You must specify at least one mapping to drop.';
+	$lang['strftsspecifyconfigtoalter'] = 'You must specify a FTS configuration to alter';
+	$lang['strftsmappingdropped'] = 'FTS mapping dropped.';
+	$lang['strftsmappingdroppedbad'] = 'FTS mapping drop failed.';
+	$lang['strftsnodictionaries'] = 'No dictionaries found.';
+	$lang['strftsmappingaltered'] = 'FTS mapping altered.';
+	$lang['strftsmappingalteredbad'] = 'FTS mapping alter failed.';
+	$lang['strftsmappingadded'] = 'FTS mapping added.';
+	$lang['strftsmappingaddedbad'] = 'FTS mapping add failed.';
+	$lang['strftstabconfigs'] = 'Configurations';
+	$lang['strftstabdicts'] = 'Dictionaries';
+	$lang['strftstabparsers'] = 'Parsers';
+	$lang['strftscantparsercopy'] = 'Can\'t specify both parser and template during text search configuration creation.';
 ?>
