@@ -3,20 +3,20 @@
 	/**
 	 * Function library read in upon startup
 	 *
-	 * $Id: lib.inc.php,v 1.111.2.5 2007/06/01 12:34:16 xzilla Exp $
+	 * $Id: lib.inc.php,v 1.123 2008/04/06 01:10:35 xzilla Exp $
 	 */
 
 	include_once('./libraries/decorator.inc.php');
 	include_once('./lang/translations.php');
-	
+
 	// Set error reporting level to max
 	error_reporting(E_ALL);
 
-	// Application name 
+	// Application name
 	$appName = 'phpPgAdmin';
 
 	// Application version
-	$appVersion = '4.1.2';
+	$appVersion = '4.2.2';
 
 	// PostgreSQL and PHP minimum version
 	$postgresqlMinVer = '7.0';
@@ -52,7 +52,7 @@
 
 	// Start session (if not auto-started)
 	if (!ini_get('session.auto_start')) {
-		session_name('PPA_ID'); 
+		session_name('PPA_ID');
 		session_start();
 	}
 
@@ -73,37 +73,39 @@
 	ini_set('magic_quotes_runtime', 0);
 	ini_set('magic_quotes_sybase', 0);
 	ini_set('arg_separator.output', '&amp;');
-	
+
 	// If login action is set, then set session variables
-	if (isset($_POST['loginServer']) && isset($_POST['loginUsername']) && 
-		isset($_POST['loginPassword'])) {
-		
+	if (isset($_POST['loginServer']) && isset($_POST['loginUsername']) &&
+		isset($_POST['loginPassword_'.md5($_POST['loginServer'])])) {
+
 		$_server_info = $misc->getServerInfo($_POST['loginServer']);
-		
+
 		$_server_info['username'] = $_POST['loginUsername'];
-		$_server_info['password'] = $_POST['loginPassword'];
-		
+		$_server_info['password'] = $_POST['loginPassword_'.md5($_POST['loginServer'])];
+
 		$misc->setServerInfo(null, $_server_info, $_POST['loginServer']);
 
 		// Check for shared credentials
 		if (isset($_POST['loginShared'])) {
 			$_SESSION['sharedUsername'] = $_POST['loginUsername'];
-			$_SESSION['sharedPassword'] = $_POST['loginPassword'];
+			$_SESSION['sharedPassword'] = $_POST['loginPassword_'.md5($_POST['loginServer'])];
 		}
-		
+
 		$_reload_browser = true;
 	}
 
 	// Determine language file to import:
+	unset($_language);
+
 	// 1. Check for the language from a request var
 	if (isset($_REQUEST['language']) && isset($appLangFiles[$_REQUEST['language']]))
 		$_language = $_REQUEST['language'];
-	
+
 	// 2. Check for language session var
 	if (!isset($_language) && isset($_SESSION['webdbLanguage']) && isset($appLangFiles[$_SESSION['webdbLanguage']])) {
 		$_language = $_SESSION['webdbLanguage'];
 	}
-	
+
 	// 3. Check for acceptable languages in HTTP_ACCEPT_LANGUAGE var
 	if (!isset($_language) && $conf['default_lang'] == 'auto' && isset($_SERVER['HTTP_ACCEPT_LANGUAGE'])) {
 		// extract acceptable language tags
@@ -142,7 +144,7 @@
 		echo $lang['strbadconfig'];
 		exit;
 	}
-	
+
 	// Check database support is properly compiled in
 	if (!function_exists('pg_connect')) {
 		echo $lang['strnotloaded'];
@@ -152,9 +154,9 @@
 	// Create data accessor object, if necessary
 	if (!isset($_no_db_connection)) {
 		if (!isset($_REQUEST['server'])) {
-			die('No server supplied!');
-			# TODO: nice error
-		}
+                        echo $lang['strnoserversupplied'];
+                        exit;
+	        }
 		$_server_info = $misc->getServerInfo();
 
 		// Redirect to the login form if not logged in
@@ -171,11 +173,11 @@
 			$_curr_db = $_server_info['defaultdb'];
 
 		include_once('./classes/database/Connection.php');
-		
+
 		// Connect to database and set the global $data variable
 		$data = $misc->getDatabaseAccessor($_curr_db);
 
-		// If schema is defined and database supports schemas, then set the 
+		// If schema is defined and database supports schemas, then set the
 		// schema explicitly.
 		if (isset($_REQUEST['database']) && isset($_REQUEST['schema']) && $data->hasSchemas()) {
 			$status = $data->setSchema($_REQUEST['schema']);
@@ -187,7 +189,7 @@
 
 		// Get database encoding
 		$dbEncoding = $data->getDatabaseEncoding();
-		
+
 		// Set client encoding to database encoding
 		if ($dbEncoding != '') {
 			// Explicitly change client encoding if it's different to server encoding.
@@ -197,7 +199,7 @@
 				$currEncoding = pg_clientencoding($data->conn->_connectionID);
 			else
 				$currEncoding = null;
-				
+
 			if ($currEncoding != $dbEncoding) {
 				$status = $data->setClientEncoding($dbEncoding);
 				if ($status != 0 && $status != -99) {
@@ -205,22 +207,25 @@
 					exit;
 				}
 			}
-					
+
 			// Override $lang['appcharset']
 			if (isset($data->codemap[$dbEncoding]))
 				$lang['appcharset'] = $data->codemap[$dbEncoding];
 			else
 				$lang['appcharset'] = $dbEncoding;
 		}
-		
-		// Load Slony if required		
+
+
+		// Load Slony if required
 		if ($_server_info['slony_support']) {
 			include('./classes/plugins/Slony.php');
 			$slony = new Slony();
 		}
 	}
 
-	// Prevent XSS attacks
-    $PHP_SELF = htmlspecialchars($_SERVER['PHP_SELF'], ENT_QUOTES, $lang['appcharset']);
-
+	if (!function_exists("htmlspecialchars_decode")) {
+		function htmlspecialchars_decode($string, $quote_style = ENT_COMPAT) {
+			return strtr($string, array_flip(get_html_translation_table(HTML_SPECIALCHARS, $quote_style)));
+		}
+	}
 ?>
